API docs for “spamfighter.core.message.test.test_attribute”

# Module s.c.m.t.test_attribute

Part of spamfighter.core.message.test View Source

Тесты на `spamfighter.core.message.attribute`.

Class | AttributeDomainTestCase | Тест на `spamfighter.core.message.attribute.AttributeDomain`.
Class | TextAttributeDomainTestCase | Тест на `spamfighter.core.message.attribute.TextAttributeDomain`.
Class | IntAttributeDomainTestCase | Тест на `spamfighter.core.message.attribute.IntAttributeDomain`.
Class | AttributeTestCase | Тест на `spamfighter.core.message.attribute.Attribute`.